cli

package
v1.8.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 5, 2026 License: MIT Imports: 13 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (

	// Baseline is the baseline tag name for track and tools commands.
	Baseline string
	// Current is the current tag name for track and tools commands.
	Current string
)
var Version = "devel"

Version is the prof CLI version. Release builds set it via -ldflags=-X=github.com/AlexsanderHamir/prof/cli.Version=... The default is used for go install from HEAD or local go build.

Functions

func CreateRootCmd

func CreateRootCmd(services *app.Services) *cobra.Command

CreateRootCmd builds the root cobra command tree. services may be nil; nil fields are filled via app.Services.WithDefaults.

func Execute

func Execute() error

Execute runs the CLI application with default (production) services.

func ExecuteWith added in v1.8.2

func ExecuteWith(services *app.Services) error

ExecuteWith runs the CLI using the given composition root. Pass nil to use app.Default.

Types

This section is empty.

Jump to