Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // Baseline is the baseline tag name for track and tools commands. Baseline string // Current is the current tag name for track and tools commands. Current string )
var Version = "devel"
Version is the prof CLI version. Release builds set it via -ldflags=-X=github.com/AlexsanderHamir/prof/cli.Version=... The default is used for go install from HEAD or local go build.
Functions ¶
func CreateRootCmd ¶
CreateRootCmd builds the root cobra command tree. services may be nil; nil fields are filled via app.Services.WithDefaults.
func Execute ¶
func Execute() error
Execute runs the CLI application with default (production) services.
func ExecuteWith ¶ added in v1.8.2
ExecuteWith runs the CLI using the given composition root. Pass nil to use app.Default.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.