Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrGoModNotFound = errors.New("go.mod not found")
ErrGoModNotFound is returned when no ancestor directory contains go.mod.
Functions ¶
func ModuleRoot ¶
ModuleRoot returns the absolute path to the Go module root by walking up from the current working directory until go.mod is found.
func TestsAssetsDir ¶
TestsAssetsDir returns <moduleRoot>/tests/assets.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.